from PySide6 import QtCharts

def create_bar_chart(rows, regions):
    data_by_regions = {}
    
    years = set()
    for row in rows:
        items = data_by_regions.setdefault(row.region_id, {})
        items[row.year] = row.population
        years.add(row.year)

    years = sorted(years)
    print('YEARS:', years)

    series = QtCharts.QHorizontalStackedBarSeries()
    series.setLabelsPrecision(20)
    series.setLabelsFormat("@value")

    for region_id, region_info in data_by_regions.items():
        region = regions[region_id]
        bar_set = QtCharts.QBarSet(region.title)
        for year in years:
            value = region_info.get(year, 0)
            bar_set.append(value) 
        bar_set.setLabelColor("#000")
        series.append(bar_set)

    series.setLabelsVisible(True)
    # series.setLabelsPosition(QtCharts.QAbstractBarSeries.LabelsPosition.LabelsCenter)

    chart = QtCharts.QChart()
    chart.addSeries(series)

    chart.createDefaultAxes()
    
    axis = QtCharts.QBarCategoryAxis()
    axis.append([str(i) for i in years])
    series.attachAxis(axis)
    chart.setAxisY(axis)

    chart.axisX().setLabelFormat("%i")
    chart.setAnimationOptions(QtCharts.QChart.AnimationOption.SeriesAnimations)

    return chart