from PySide6 import QtCore

class PopulationModel(QtCore.QAbstractTableModel):
    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)

        self.rows = []
        self.regions = []

    def setRows(self, rows):
        self.rows = rows

    def setRegions(self, regions):
        self.regions = regions

    def data(self, index: QtCore.QModelIndex, role):
        if not index.isValid():
            return

        row = index.row()
        col = index.column()
        if role == QtCore.Qt.ItemDataRole.DisplayRole:
            if col == 0:
                return self.rows[row].id
            elif col == 1:
                region_title = self.regions[self.rows[row].region_id].title
                return region_title
            elif col == 2:
                return self.rows[row].year
            elif col == 3:
                return self.rows[row].population
        elif role == QtCore.Qt.ItemDataRole.UserRole:
            return self.rows[row]

    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...):
        if role == QtCore.Qt.ItemDataRole.DisplayRole:
            if orientation == QtCore.Qt.Orientation.Horizontal:
                return {
                    0: "id",
                    1: "Регион",
                    2: "Год",
                    3: "Население, чел.",
                }.get(section)
            elif orientation == QtCore.Qt.Orientation.Vertical:
                return

        return super().headerData(section, orientation, role)
    
    def rowCount(self, parent) -> int:
        return len(self.rows)
    
    def columnCount(self, parent) -> int:
        return 4